@@ -1,3 +1,5 @@
+/* -*- mode: C; c-file-style: "gnu"; indent-tabs-mode: nil; -*- */
+
 /* Metacity window placement */
 
 /* 
@@ -922,11 +924,14 @@ meta_window_place (MetaWindow        *window,
                                               &workarea);      
       meta_window_get_outer_rect (window, &outer);
       
-      if (outer.width >= workarea.width)
-        window->maximize_horizontally_after_placement = TRUE;
-
-      if (outer.height >= workarea.height)
-        window->maximize_vertically_after_placement = TRUE;
+      /* If the window is bigger than the screen, then automaximize.  Do NOT
+       * auto-maximize the directions independently.  See #419810.
+       */
+      if (outer.width >= workarea.width && outer.height >= workarea.height)
+        {
+          window->maximize_horizontally_after_placement = TRUE;
+          window->maximize_vertically_after_placement = TRUE;
+        }
     }
 
  done_check_denied_focus:
