@@ -89,7 +89,7 @@ set_wm_check_hint (MetaScreen *screen)
 static int
 set_supported_hint (MetaScreen *screen)
 {
-#define N_SUPPORTED 58
+#define N_SUPPORTED 62
   Atom atoms[N_SUPPORTED];
   
   atoms[0] = screen->display->atom_net_wm_name;
@@ -150,8 +150,12 @@ set_supported_hint (MetaScreen *screen)
   atoms[55] = screen->display->atom_net_wm_state_demands_attention;
   atoms[56] = screen->display->atom_net_desktop_geometry;
   atoms[57] = screen->display->atom_net_desktop_viewport;
-  //atoms[58] = screen->display->atom_net_restack_window;
-  //atoms[59] = screen->display->atom_net_moveresize_window;
+  atoms[58] = screen->display->atom_net_wm_user_time_window;
+  atoms[59] = screen->display->atom_net_moveresize_window;
+  atoms[60] = screen->display->atom_net_wm_action_above;
+  atoms[61] = screen->display->atom_net_wm_action_below;
+
+  /* atoms[58] = screen->display->atom_net_restack_window; */
   
   XChangeProperty (screen->display->xdisplay, screen->xroot,
                    screen->display->atom_net_supported,
@@ -986,7 +990,7 @@ meta_screen_queue_frame_redraws (MetaScreen *screen)
 static void
 queue_resize (MetaScreen *screen, MetaWindow *window, gpointer data)
 {
-  meta_window_queue_move_resize (window);
+  meta_window_queue (window, META_QUEUE_MOVE_RESIZE);
 }
 
 void
@@ -2215,7 +2219,7 @@ meta_screen_resize_func (MetaScreen *screen,
     {
       meta_window_update_struts (window);
     }
-  meta_window_queue_move_resize (window);
+  meta_window_queue (window, META_QUEUE_MOVE_RESIZE);
 
   meta_window_recalc_features (window);
 }
@@ -2268,7 +2272,7 @@ queue_windows_showing (MetaScreen *screen)
       MetaWindow *w = tmp->data;
 
       if (w->screen == screen)
-        meta_window_queue_calc_showing (w);
+        meta_window_queue (w, META_QUEUE_CALC_SHOWING);
       
       tmp = tmp->next;
     }
@@ -2542,15 +2546,7 @@ meta_screen_sn_event (SnMonitorEvent *event,
 }
 #endif
 
-/* Sets the initial_timestamp and initial_workspace properties
- * of a window according to information given us by the
- * startup-notification library.
- *
- * Returns TRUE if startup properties have been applied, and
- * FALSE if they have not (for example, if they had already
- * been applied.)
- */
-gboolean
+void
 meta_screen_apply_startup_properties (MetaScreen *screen,
                                       MetaWindow *window)
 {
@@ -2559,7 +2555,6 @@ meta_screen_apply_startup_properties (MetaScreen *screen,
   GSList *tmp;
   SnStartupSequence *sequence;
   
-  /* Does the window have a startup ID stored? */
   startup_id = meta_window_get_startup_id (window);
 
   meta_topic (META_DEBUG_STARTUP,
@@ -2570,10 +2565,6 @@ meta_screen_apply_startup_properties (MetaScreen *screen,
   sequence = NULL;
   if (startup_id == NULL)
     {
-      /* No startup ID stored for the window. Let's ask the
-       * startup-notification library whether there's anything
-       * stored for the resource name or resource class hints.
-       */
       tmp = screen->startup_sequences;
       while (tmp != NULL)
         {
@@ -2606,14 +2597,9 @@ meta_screen_apply_startup_properties (MetaScreen *screen,
         }
     }
 
-  /* Still no startup ID? Bail. */
   if (startup_id == NULL)
-    return FALSE;
+    return;
   
-  /* We might get this far and not know the sequence ID (if the window
-   * already had a startup ID stored), so let's look for one if we don't
-   * already know it.
-   */
   if (sequence == NULL)
     {
       tmp = screen->startup_sequences;
@@ -2635,7 +2621,8 @@ meta_screen_apply_startup_properties (MetaScreen *screen,
 
   if (sequence != NULL)
     {
-      gboolean changed_something = FALSE;
+      int space;
+      guint32 timestamp;
           
       meta_topic (META_DEBUG_STARTUP,
                   "Found startup sequence for window %s ID \"%s\"\n",
@@ -2643,7 +2630,7 @@ meta_screen_apply_startup_properties (MetaScreen *screen,
 
       if (!window->initial_workspace_set)
         {
-          int space = sn_startup_sequence_get_workspace (sequence);
+          space = sn_startup_sequence_get_workspace (sequence);
           if (space >= 0)
             {
               meta_topic (META_DEBUG_STARTUP,
@@ -2652,23 +2639,21 @@ meta_screen_apply_startup_properties (MetaScreen *screen,
               
               window->initial_workspace_set = TRUE;
               window->initial_workspace = space;
-              changed_something = TRUE;
             }
         }
 
       if (!window->initial_timestamp_set)
         {
-          guint32 timestamp = sn_startup_sequence_get_timestamp (sequence);
+          timestamp = sn_startup_sequence_get_timestamp (sequence);
           meta_topic (META_DEBUG_STARTUP,
                       "Setting initial window timestamp to %u based on startup info\n",
                       timestamp);
               
           window->initial_timestamp_set = TRUE;
           window->initial_timestamp = timestamp;
-          changed_something = TRUE;
         }
 
-      return changed_something;
+      return;
     }
   else
     {
@@ -2678,7 +2663,5 @@ meta_screen_apply_startup_properties (MetaScreen *screen,
     }
   
 #endif /* HAVE_STARTUP_NOTIFICATION */
-
-  return FALSE;
 }
 
